showColumnName property
Decides whether the column name should be displayed along with the content of Clear Filter option .
Implementation
final bool showColumnName;
Decides whether the column name should be displayed along with the content of Clear Filter option .
final bool showColumnName;